==> ompss-17.12.tar.gz: ompss-17.12/mcxx-2.1.0/src/driver/cxx-debugflags.c <==
/* ANSI-C code produced by gperf version 3.0.4 */
/* Command-line: gperf --language=ANSI-C --hash-function-name=debugflags_hash --struct-type --lookup-function-name=debugflags_lookup --output=src/driver/cxx-debugflags.c --global-table --word-array-name=debugflags_list --initializer-suffix=',0,""' ./src/driver/cxx-debugflags.gperf  */
/* Computed positions: -k'8,10' */

#if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
      && ('%' == 37) && ('&' == 38) && ('\'' == 39) && ('(' == 40) \
      && (')' == 41) && ('*' == 42) && ('+' == 43) && (',' == 44) \
      && ('-' == 45) && ('.' == 46) && ('/' == 47) && ('0' == 48) \
      && ('1' == 49) && ('2' == 50) && ('3' == 51) && ('4' == 52) \
      && ('5' == 53) && ('6' == 54) && ('7' == 55) && ('8' == 56) \
      && ('9' == 57) && (':' == 58) && (';' == 59) && ('<' == 60) \
      && ('=' == 61) && ('>' == 62) && ('?' == 63) && ('A' == 65) \
      && ('B' == 66) && ('C' == 67) && ('D' == 68) && ('E' == 69) \
      && ('F' == 70) && ('G' == 71) && ('H' == 72) && ('I' == 73) \
      && ('J' == 74) && ('K' == 75) && ('L' == 76) && ('M' == 77) \
      && ('N' == 78) && ('O' == 79) && ('P' == 80) && ('Q' == 81) \
      && ('R' == 82) && ('S' == 83) && ('T' == 84) && ('U' == 85) \
      && ('V' == 86) && ('W' == 87) && ('X' == 88) && ('Y' == 89) \
      && ('Z' == 90) && ('[' == 91) && ('\\' == 92) && (']' == 93) \
      && ('^' == 94) && ('_' == 95) && ('a' == 97) && ('b' == 98) \
      && ('c' == 99) && ('d' == 100) && ('e' == 101) && ('f' == 102) \
      && ('g' == 103) && ('h' == 104) && ('i' == 105) && ('j' == 106) \
      && ('k' == 107) && ('l' == 108) && ('m' == 109) && ('n' == 110) \
      && ('o' == 111) && ('p' == 112) && ('q' == 113) && ('r' == 114) \
      && ('s' == 115) && ('t' == 116) && ('u' == 117) && ('v' == 118) \
      && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
      && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
/* The character set is not based on ISO-646.  */
#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gnu-gperf@gnu.org>."
#endif

#line 28 "./src/driver/cxx-debugflags.gperf"

#include <stdlib.h>
#include <string.h>
#include "cxx-driver.h"
#include "cxx-utils.h"

#define DEBUG_OPTION_REF(x) (offsetof(struct debug_options_tag, x))
#line 37 "./src/driver/cxx-debugflags.gperf"
struct debug_flags_list_t;

#define TOTAL_KEYWORDS 31
#define MIN_WORD_LENGTH 9
#define MAX_WORD_LENGTH 22
#define MIN_HASH_VALUE 9
#define MAX_HASH_VALUE 47
/* maximum key range = 39, duplicates = 0 */

#ifdef __GNUC__
__inline
#else
#ifdef __cplusplus
inline
#endif
#endif
static unsigned int
debugflags_hash (register const char *str, register unsigned int len)
{
  static unsigned char asso_values[] =
    {
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 28, 48, 30, 25,  0,
       5,  0, 48,  0, 48, 15, 23, 48,  5,  0,
      10,  5,  5, 48,  5,  0,  0, 48, 15, 48,
      48, 48, 20, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48, 48, 48, 48, 48,
      48, 48, 48, 48, 48, 48
    };
  register int hval = len;

  switch (hval)
    {
      default:
        hval += asso_values[(unsigned char)str[9]];
      /*FALLTHROUGH*/
      case 9:
      case 8:
        hval += asso_values[(unsigned char)str[7]];
        break;
    }
  return hval;
}

static struct debug_flags_list_t debugflags_list[] =
  {
    {"",0,""}, {"",0,""}, {"",0,""}, {"",0,""}, {"",0,""},
    {"",0,""}, {"",0,""}, {"",0,""}, {"",0,""},
#line 53 "./src/driver/cxx-debugflags.gperf"
    {"print_ast", DEBUG_OPTION_REF(print_ast_graphviz), "Prints ast tree, the tree generated by the parser in Graphviz"},
#line 58 "./src/driver/cxx-debugflags.gperf"
    {"print_pcfg", DEBUG_OPTION_REF(print_pcfg), "Prints PCFG in graphviz format"},
#line 45 "./src/driver/cxx-debugflags.gperf"
    {"debug_lexer", DEBUG_OPTION_REF(debug_lexer), "Enables lexer debug"},
#line 44 "./src/driver/cxx-debugflags.gperf"
    {"binary_check", DEBUG_OPTION_REF(binary_check), "Performs a binary check between the binary output"},
    {"",0,""},
#line 63 "./src/driver/cxx-debugflags.gperf"
    {"print_tdg", DEBUG_OPTION_REF(print_tdg), "Prints TDG in graphviz format"},
#line 59 "./src/driver/cxx-debugflags.gperf"
    {"print_pcfg_full", DEBUG_OPTION_REF(print_pcfg_full), "Prints PCFG in graphviz format with Context nodes and Analysis information"},
#line 62 "./src/driver/cxx-debugflags.gperf"
    {"print_scope", DEBUG_OPTION_REF(print_scope), "Prints scope of the translation unit"},
#line 54 "./src/driver/cxx-debugflags.gperf"
    {"print_nodecl", DEBUG_OPTION_REF(print_nodecl_graphviz), "Alias of print_nodecl_graphviz"},
#line 41 "./src/driver/cxx-debugflags.gperf"
    {"analysis_perf", DEBUG_OPTION_REF(analysis_perf), "Prints the performance information of the static analysis"},
#line 48 "./src/driver/cxx-debugflags.gperf"
    {"do_not_codegen", DEBUG_OPTION_REF(do_not_codegen), "Does not perform codegen step"},
#line 61 "./src/driver/cxx-debugflags.gperf"
    {"print_pcfg_w_context", DEBUG_OPTION_REF(print_pcfg_w_context), "Prints PCFG in graphviz format with Context nodes"},
#line 60 "./src/driver/cxx-debugflags.gperf"
    {"print_pcfg_w_analysis", DEBUG_OPTION_REF(print_pcfg_w_analysis), "Prints PCFG in graphviz format with Analysis information"},
#line 56 "./src/driver/cxx-debugflags.gperf"
    {"print_nodecl_html", DEBUG_OPTION_REF(print_nodecl_html), "Prints nodecl tree in HTML format (requires Javascript-enabled browser)"},
#line 51 "./src/driver/cxx-debugflags.gperf"
    {"memory_report", DEBUG_OPTION_REF(print_memory_report), "Prints a memory report at the end"},
#line 65 "./src/driver/cxx-debugflags.gperf"
    {"show_template_packs", DEBUG_OPTION_REF(show_template_packs), "Adds a marker to show the extent of a template pack expansion"},
    {"",0,""},
#line 55 "./src/driver/cxx-debugflags.gperf"
    {"print_nodecl_graphviz", DEBUG_OPTION_REF(print_nodecl_graphviz), "Prints nodecl tree in graphviz format"},
#line 47 "./src/driver/cxx-debugflags.gperf"
    {"debug_sizeof", DEBUG_OPTION_REF(debug_sizeof), "Enables special debug messages for sizeof"},
#line 40 "./src/driver/cxx-debugflags.gperf"
    {"analysis_info", DEBUG_OPTION_REF(analysis_info), "Adds analysis information in text format in the source code"},
#line 49 "./src/driver/cxx-debugflags.gperf"
    {"do_not_run_gdb", DEBUG_OPTION_REF(do_not_run_gdb), "Disables the output of a backtrace using 'gdb' debugger when a signal handler is called"},
    {"",0,""},
#line 42 "./src/driver/cxx-debugflags.gperf"
    {"analysis_verbose", DEBUG_OPTION_REF(analysis_verbose), "Prints the results of the static analysis"},
#line 52 "./src/driver/cxx-debugflags.gperf"
    {"memory_report_in_bytes", DEBUG_OPTION_REF(print_memory_report_in_bytes), "The memory report is written in bytes"},
#line 66 "./src/driver/cxx-debugflags.gperf"
    {"stats_string_table", DEBUG_OPTION_REF(stats_string_table), "Prints statistics of the global string table"},
#line 64 "./src/driver/cxx-debugflags.gperf"
    {"ranges_verbose", DEBUG_OPTION_REF(ranges_verbose), "Prints debug information about range analysis"},
    {"",0,""},
#line 68 "./src/driver/cxx-debugflags.gperf"
    {"tdg_verbose", DEBUG_OPTION_REF(tdg_verbose), "Prints debug information about static Task Dependency Graph generation"},
#line 39 "./src/driver/cxx-debugflags.gperf"
    {"abort_on_ice", DEBUG_OPTION_REF(abort_on_ice), "When an error condition is detected, compiler will raise SIGABRT signal. This is useful for debugging"},
    {"",0,""},
#line 67 "./src/driver/cxx-debugflags.gperf"
    {"tdg_to_json", DEBUG_OPTION_REF(tdg_to_json), "Prints TDG in a predefined JSON format"},
    {"",0,""},
#line 69 "./src/driver/cxx-debugflags.gperf"
    {"vectorization_verbose", DEBUG_OPTION_REF(vectorization_verbose), "Enable vectorization debug messages"},
#line 46 "./src/driver/cxx-debugflags.gperf"
    {"debug_parser", DEBUG_OPTION_REF(debug_parser), "Enables parser debug"},
    {"",0,""},
#line 43 "./src/driver/cxx-debugflags.gperf"
    {"backtrace_on_ice", DEBUG_OPTION_REF(backtrace_on_ice), "When an error condition is detected, compiler will print a backtrace to the stderr"},
    {"",0,""},
#line 57 "./src/driver/cxx-debugflags.gperf"
    {"print_parse_tree", DEBUG_OPTION_REF(print_ast_graphviz), "Deprecated alias of print_ast"},
#line 50 "./src/driver/cxx-debugflags.gperf"
    {"enable_debug_code", DEBUG_OPTION_REF(enable_debug_code), "Enable debug code, in general these are debug messages"}
  };

#ifdef __GNUC__
__inline
#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
__attribute__ ((__gnu_inline__))
#endif
#endif
struct debug_flags_list_t *
debugflags_lookup (register const char *str, register unsigned int len)
{
  if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
    {
      register int key = debugflags_hash (str, len);

      if (key <= MAX_HASH_VALUE && key >= 0)
        {
          register const char *s = debugflags_list[key].name;

          if (*str == *s && !strcmp (str + 1, s + 1))
            return &debugflags_list[key];
        }
    }
  return 0;
}
#line 70 "./src/driver/cxx-debugflags.gperf"


static int cmpstringp(const void *p1, const void *p2)
{
    struct debug_flags_list_t** df1 = (struct debug_flags_list_t**) p1;
    struct debug_flags_list_t** df2 = (struct debug_flags_list_t**) p2;

    return strcmp((*df1)->name, (*df2)->name);
}

struct debug_flags_list_t** list_of_debug_flags(void)
{
    struct debug_flags_list_t** result = NULL;

    int i = 0;
    int j = 0;
    while (i < TOTAL_KEYWORDS)
    {
        const char* keyword = debugflags_list[j].name;

        if (keyword != NULL && *keyword != '\0')
        {
            P_LIST_ADD(result, i, &(debugflags_list[j]));
        }

        j++;
    }

    P_LIST_ADD(result, i, NULL);

    qsort(result, i-1, sizeof(struct debug_flags_list_t *), cmpstringp);

    return result;
}

==> ompss-19.06.tar.gz: ompss-19.06/mcxx-2.3.0/src/driver/cxx-debugflags.c <==
/* ANSI-C code produced by gperf version 3.0.4 */
/* Command-line: gperf --language=ANSI-C --hash-function-name=debugflags_hash --struct-type --lookup-function-name=debugflags_lookup --output=src/driver/cxx-debugflags.c --global-table --word-array-name=debugflags_list --initializer-suffix=',0,""' ./src/driver/cxx-debugflags.gperf  */
/* Computed positions: -k'8,10' */

#if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
      && ('%' == 37) && ('&' == 38) && ('\'' == 39) && ('(' == 40) \
      && (')' == 41) && ('*' == 42) && ('+' == 43) && (',' == 44) \
      && ('-' == 45) && ('.' == 46) && ('/' == 47) && ('0' == 48) \
      && ('1' == 49) && ('2' == 50) && ('3' == 51) && ('4' == 52) \
      && ('5' == 53) && ('6' == 54) && ('7' == 55) && ('8' == 56) \
      && ('9' == 57) && (':' == 58) && (';' == 59) && ('<' == 60) \
      && ('=' == 61) && ('>' == 62) && ('?' == 63) && ('A' == 65) \
      && ('B' == 66) && ('C' == 67) && ('D' == 68) && ('E' == 69) \
      && ('F' == 70) && ('G' == 71) && ('H' == 72) && ('I' == 73) \
      && ('J' == 74) && ('K' == 75) && ('L' == 76) && ('M' == 77) \
      && ('N' == 78) && ('O' == 79) && ('P' == 80) && ('Q' == 81) \
      && ('R' == 82) && ('S' == 83) && ('T' == 84) && ('U' == 85) \
      && ('V' == 86) && ('W' == 87) && ('X' == 88) && ('Y' == 89) \
      && ('Z' == 90) && ('[' == 91) && ('\\' == 92) && (']' == 93) \
      && ('^' == 94) && ('_' == 95) && ('a' == 97) && ('b' == 98) \
      && ('c' == 99) && ('d' == 100) && ('e' == 101) && ('f' == 102) \
      && ('g' == 103) && ('h' == 104) && ('i' == 105) && ('j' == 106) \
      && ('k' == 107) && ('l' == 108) && ('m' == 109) && ('n' == 110) \
      && ('o' == 111) && ('p' == 112) && ('q' == 113) && ('r' == 114) \
      && ('s' == 115) && ('t' == 116) && ('u' == 117) && ('v' == 118) \
      && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
      && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
/* The character set is not based on ISO-646.  */
#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gnu-gperf@gnu.org>."
#endif

#line 28 "./src/driver/cxx-debugflags.gperf"

#include <stdlib.h>
#include <string.h>
#include "cxx-driver.h"
#include "cxx-utils.h"

#define DEBUG_OPTION_REF(x) (offsetof(struct debug_options_tag, x))
#line 37 "./src/driver/cxx-debugflags.gperf"
struct debug_flags_list_t;

#define TOTAL_KEYWORDS 32
#define MIN_WORD_LENGTH 9
#define MAX_WORD_LENGTH 22
#define MIN_HASH_VALUE 9
#define MAX_HASH_VALUE 56
/* maximum key range = 48, duplicates = 0 */

#ifdef __GNUC__
__inline
#else
#ifdef __cplusplus
inline
#endif
#endif
static unsigned int
debugflags_hash (register const char *str, register unsigned int len)
{
  static unsigned char asso_values[] =
    {
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 35, 57, 40, 25,  0,
       5,  0, 57,  0, 57, 25, 30, 57,  5,  5,
       5,  5,  5, 57,  5,  0,  0, 57, 15, 57,
      57, 57, 20, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57, 57, 57, 57, 57,
      57, 57, 57, 57, 57, 57
    };
  register int hval = len;

  switch (hval)
    {
      default:
        hval += asso_values[(unsigned char)str[9]];
      /*FALLTHROUGH*/
      case 9:
      case 8:
        hval += asso_values[(unsigned char)str[7]];
        break;
    }
  return hval;
}

static struct debug_flags_list_t debugflags_list[] =
  {
    {"",0,""}, {"",0,""}, {"",0,""}, {"",0,""}, {"",0,""},
    {"",0,""}, {"",0,""}, {"",0,""}, {"",0,""},
#line 54 "./src/driver/cxx-debugflags.gperf"
    {"print_ast", DEBUG_OPTION_REF(print_ast_graphviz), "Prints ast tree, the tree generated by the parser in Graphviz"},
#line 59 "./src/driver/cxx-debugflags.gperf"
    {"print_pcfg", DEBUG_OPTION_REF(print_pcfg), "Prints PCFG in graphviz format"},
#line 46 "./src/driver/cxx-debugflags.gperf"
    {"debug_lexer", DEBUG_OPTION_REF(debug_lexer), "Enables lexer debug"},
#line 45 "./src/driver/cxx-debugflags.gperf"
    {"binary_check", DEBUG_OPTION_REF(binary_check), "Performs a binary check between the binary output"},
    {"",0,""},
#line 64 "./src/driver/cxx-debugflags.gperf"
    {"print_tdg", DEBUG_OPTION_REF(print_tdg), "Prints TDG in graphviz format"},
#line 60 "./src/driver/cxx-debugflags.gperf"
    {"print_pcfg_full", DEBUG_OPTION_REF(print_pcfg_full), "Prints PCFG in graphviz format with Context nodes and Analysis information"},
#line 63 "./src/driver/cxx-debugflags.gperf"
    {"print_scope", DEBUG_OPTION_REF(print_scope), "Prints scope of the translation unit"},
#line 55 "./src/driver/cxx-debugflags.gperf"
    {"print_nodecl", DEBUG_OPTION_REF(print_nodecl_graphviz), "Alias of print_nodecl_graphviz"},
#line 42 "./src/driver/cxx-debugflags.gperf"
    {"analysis_perf", DEBUG_OPTION_REF(analysis_perf), "Prints the performance information of the static analysis"},
#line 49 "./src/driver/cxx-debugflags.gperf"
    {"do_not_codegen", DEBUG_OPTION_REF(do_not_codegen), "Does not perform codegen step"},
#line 62 "./src/driver/cxx-debugflags.gperf"
    {"print_pcfg_w_context", DEBUG_OPTION_REF(print_pcfg_w_context), "Prints PCFG in graphviz format with Context nodes"},
#line 61 "./src/driver/cxx-debugflags.gperf"
    {"print_pcfg_w_analysis", DEBUG_OPTION_REF(print_pcfg_w_analysis), "Prints PCFG in graphviz format with Analysis information"},
#line 57 "./src/driver/cxx-debugflags.gperf"
    {"print_nodecl_html", DEBUG_OPTION_REF(print_nodecl_html), "Prints nodecl tree in HTML format (requires Javascript-enabled browser)"},
#line 52 "./src/driver/cxx-debugflags.gperf"
    {"memory_report", DEBUG_OPTION_REF(print_memory_report), "Prints a memory report at the end"},
#line 50 "./src/driver/cxx-debugflags.gperf"
    {"do_not_run_gdb", DEBUG_OPTION_REF(do_not_run_gdb), "Disables the output of a backtrace using 'gdb' debugger when a signal handler is called"},
    {"",0,""},
#line 56 "./src/driver/cxx-debugflags.gperf"
    {"print_nodecl_graphviz", DEBUG_OPTION_REF(print_nodecl_graphviz), "Prints nodecl tree in graphviz format"},
#line 40 "./src/driver/cxx-debugflags.gperf"
    {"abort_on_error_message", DEBUG_OPTION_REF(abort_on_error_message), "When an error diagnostic is emitted, the compiler will raise a SIGABRT signal. This is useful for debugging"},
    {"",0,""},
#line 66 "./src/driver/cxx-debugflags.gperf"
    {"show_template_packs", DEBUG_OPTION_REF(show_template_packs), "Adds a marker to show the extent of a template pack expansion"},
    {"",0,""},
#line 43 "./src/driver/cxx-debugflags.gperf"
    {"analysis_verbose", DEBUG_OPTION_REF(analysis_verbose), "Prints the results of the static analysis"},
#line 53 "./src/driver/cxx-debugflags.gperf"
    {"memory_report_in_bytes", DEBUG_OPTION_REF(print_memory_report_in_bytes), "The memory report is written in bytes"},
    {"",0,""},
#line 65 "./src/driver/cxx-debugflags.gperf"
    {"ranges_verbose", DEBUG_OPTION_REF(ranges_verbose), "Prints debug information about range analysis"},
    {"",0,""},
#line 69 "./src/driver/cxx-debugflags.gperf"
    {"tdg_verbose", DEBUG_OPTION_REF(tdg_verbose), "Prints debug information about static Task Dependency Graph generation"},
#line 48 "./src/driver/cxx-debugflags.gperf"
    {"debug_sizeof", DEBUG_OPTION_REF(debug_sizeof), "Enables special debug messages for sizeof"},
#line 41 "./src/driver/cxx-debugflags.gperf"
    {"analysis_info", DEBUG_OPTION_REF(analysis_info), "Adds analysis information in text format in the source code"},
    {"",0,""}, {"",0,""},
#line 70 "./src/driver/cxx-debugflags.gperf"
    {"vectorization_verbose", DEBUG_OPTION_REF(vectorization_verbose), "Enable vectorization debug messages"},
#line 39 "./src/driver/cxx-debugflags.gperf"
    {"abort_on_ice", DEBUG_OPTION_REF(abort_on_ice), "When an error condition is detected, the compiler will raise a SIGABRT signal. This is useful for debugging"},
#line 67 "./src/driver/cxx-debugflags.gperf"
    {"stats_string_table", DEBUG_OPTION_REF(stats_string_table), "Prints statistics of the global string table"},
    {"",0,""}, {"",0,""},
#line 68 "./src/driver/cxx-debugflags.gperf"
    {"tdg_to_json", DEBUG_OPTION_REF(tdg_to_json), "Prints TDG in a predefined JSON format"},
#line 51 "./src/driver/cxx-debugflags.gperf"
    {"enable_debug_code", DEBUG_OPTION_REF(enable_debug_code), "Enable debug code, in general these are debug messages"},
    {"",0,""}, {"",0,""}, {"",0,""},
#line 44 "./src/driver/cxx-debugflags.gperf"
    {"backtrace_on_ice", DEBUG_OPTION_REF(backtrace_on_ice), "When an error condition is detected, compiler will print a backtrace to the stderr"},
#line 47 "./src/driver/cxx-debugflags.gperf"
    {"debug_parser", DEBUG_OPTION_REF(debug_parser), "Enables parser debug"},
    {"",0,""}, {"",0,""}, {"",0,""},
#line 58 "./src/driver/cxx-debugflags.gperf"
    {"print_parse_tree", DEBUG_OPTION_REF(print_ast_graphviz), "Deprecated alias of print_ast"}
  };

#ifdef __GNUC__
__inline
#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
__attribute__ ((__gnu_inline__))
#endif
#endif
struct debug_flags_list_t *
debugflags_lookup (register const char *str, register unsigned int len)
{
  if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
    {
      register int key = debugflags_hash (str, len);

      if (key <= MAX_HASH_VALUE && key >= 0)
        {
          register const char *s = debugflags_list[key].name;

          if (*str == *s && !strcmp (str + 1, s + 1))
            return &debugflags_list[key];
        }
    }
  return 0;
}
#line 71 "./src/driver/cxx-debugflags.gperf"


static int cmpstringp(const void *p1, const void *p2)
{
    struct debug_flags_list_t** df1 = (struct debug_flags_list_t**) p1;
    struct debug_flags_list_t** df2 = (struct debug_flags_list_t**) p2;

    return strcmp((*df1)->name, (*df2)->name);
}

struct debug_flags_list_t** list_of_debug_flags(void)
{
    struct debug_flags_list_t** result = NULL;

    int i = 0;
    int j = 0;
    while (i < TOTAL_KEYWORDS)
    {
        const char* keyword = debugflags_list[j].name;

        if (keyword != NULL && *keyword != '\0')
        {
            P_LIST_ADD(result, i, &(debugflags_list[j]));
        }

        j++;
    }

    P_LIST_ADD(result, i, NULL);

    qsort(result, i-1, sizeof(struct debug_flags_list_t *), cmpstringp);

    return result;
}
